# Generated by Django 2.1 on 2018-09-04 12:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [('django_x509', '0005_organizational_unit_name')]

    operations = [
        migrations.AddField(
            model_name='ca',
            name='passphrase',
            field=models.CharField(
                blank=True,
                help_text='Passphrase for the private key, if present',
                max_length=64,
            ),
        ),
        migrations.AddField(
            model_name='cert',
            name='passphrase',
            field=models.CharField(
                blank=True,
                help_text='Passphrase for the private key, if present',
                max_length=64,
            ),
        ),
    ]
