# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2017-11-03 11:31
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [('django_x509', '0002_certificate')]

    operations = [
        migrations.RenameField(
            model_name='ca', old_name='organization', new_name='organization_name'
        ),
        migrations.RenameField(
            model_name='cert', old_name='organization', new_name='organization_name'
        ),
    ]
